==> hystrix-javanica-1.4.1-sources.jar: com/netflix/hystrix/contrib/javanica/command/CommandExecutionAction.java <==
/**
 * Copyright 2012 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.netflix.hystrix.contrib.javanica.command;

import com.netflix.hystrix.contrib.javanica.exception.CommandActionExecutionException;

/**
 * Action to execute a Hystrix command.
 */
public class CommandExecutionAction extends CommandAction {

    private AbstractHystrixCommand hystrixCommand;

    /**
     * Constructor with parameters.
     *
     * @param hystrixCommand the hystrix command to execute.
     */
    public CommandExecutionAction(AbstractHystrixCommand hystrixCommand) {
        this.hystrixCommand = hystrixCommand;
    }

    public AbstractHystrixCommand getHystrixCommand() {
        return hystrixCommand;
    }

    @Override
    public Object execute(ExecutionType executionType) throws CommandActionExecutionException {
        return CommandExecutor.execute(hystrixCommand, executionType);
    }

    @Override
    public Object executeWithArgs(ExecutionType executionType, Object[] args) throws CommandActionExecutionException {
        return CommandExecutor.execute(hystrixCommand, executionType);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getActionName() {
        if (hystrixCommand != null) {
            return hystrixCommand.getCommandKey().name();
        }
        return "";
    }

}

==> hystrix-javanica-1.4.20-sources.jar: com/netflix/hystrix/contrib/javanica/command/CommandExecutionAction.java <==
/**
 * Copyright 2012 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.netflix.hystrix.contrib.javanica.command;

import com.netflix.hystrix.contrib.javanica.exception.CommandActionExecutionException;

/**
 * Action to execute a Hystrix command.
 */
public class CommandExecutionAction extends CommandAction {

    private AbstractHystrixCommand hystrixCommand;
    private  MetaHolder metaHolder;

    /**
     * Constructor with parameters.
     *
     * @param hystrixCommand the hystrix command to execute.
     */
    public CommandExecutionAction(AbstractHystrixCommand hystrixCommand, MetaHolder metaHolder) {
        this.hystrixCommand = hystrixCommand;
        this.metaHolder = metaHolder;
    }

    public AbstractHystrixCommand getHystrixCommand() {
        return hystrixCommand;
    }

    @Override
    public MetaHolder getMetaHolder() {
        return metaHolder;
    }

    @Override
    public Object execute(ExecutionType executionType) throws CommandActionExecutionException {
        return CommandExecutor.execute(hystrixCommand, executionType, metaHolder);
    }

    @Override
    public Object executeWithArgs(ExecutionType executionType, Object[] args) throws CommandActionExecutionException {
        return CommandExecutor.execute(hystrixCommand, executionType, metaHolder);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getActionName() {
        if (hystrixCommand != null) {
            return hystrixCommand.getCommandKey().name();
        }
        return "";
    }

}
